@@ -26,7 +26,7 @@
 #include "helpmsgs.h"
 
 const struct helpmessage hlp_listkeys = {
-  N_("Keystrokes"), N_("\
+	N_("Keystrokes"), N_("\
 Motion keys: Next/Previous, Top/End, Up/Down, Backwards/Forwards:\n\
   j, Down-arrow         k, Up-arrow             move highlight\n\
   N, Page-down, Space   P, Page-up, Backspace   scroll list by 1 page\n\
@@ -38,7 +38,7 @@ Motion keys: Next/Previous, Top/End, Up/Down, Backwards/Forwards:\n\
   ^b                    ^f                      pan display by 1 character\n\n\
 \
 Mark packages for later processing:\n\
- +, Insert  install or upgrade      =, H  hold in present state\n\
+ +, Insert  install or upgrade      =, H  hold in present version\n\
  -, Delete  remove                  :, G  unhold: upgrade or leave uninstalled\n\
  _          remove & purge config\n\
                                              Miscellaneous:\n\
@@ -52,7 +52,7 @@ Quit, exit, overwrite (note capitals!):       ?, F1 request help (also Help)\n\
 };
 
 const struct helpmessage hlp_mainintro = {
-  N_("Introduction to package selections"), N_("\
+	N_("Introduction to package selections"), N_("\
 Welcome to dselect's main package listing.\n\n\
 \
 You will be presented with a list of packages which are installed or available\n\
@@ -77,7 +77,7 @@ Press <space> to leave help and enter the list now.\n")
 };
 
 const struct helpmessage hlp_readonlyintro = {
-  N_("Introduction to read-only package list browser"), N_("\
+	N_("Introduction to read-only package list browser"), N_("\
 Welcome to dselect's main package listing.\n\n\
 \
 You will be presented with a list of packages which are installed or available\n\
@@ -96,7 +96,7 @@ Press <space> to leave help and enter the list now.\n")
 };
 
 const struct helpmessage hlp_recurintro = {
-  N_("Introduction to conflict/dependency resolution sub-list"), N_("\
+	N_("Introduction to conflict/dependency resolution sub-list"), N_("\
 Dependency/conflict resolution - introduction.\n\n\
 \
 One or more of your choices have raised a conflict or dependency problem -\n\
@@ -105,7 +105,7 @@ some combinations of packages may not be installed together.\n\n\
 \
 You will see a sub-list containing the packages involved.  The bottom half of\n\
 the display shows relevant conflicts and dependencies; use 'i' to cycle between\n\
-that, the package descriptions and the internal control information.\n\n\
+that, the package descriptions and the internal package metadata.\n\n\
 \
 A set of 'suggested' packages has been calculated, and the initial markings in\n\
 this sub-list have been set to match those, so you can just hit Return to\n\
@@ -115,14 +115,14 @@ the problem(s), and go back to the main list, by pressing capital 'X'.\n\n\
 You can also move around the list and change the markings so that they are more\n\
 like what you want, and you can 'reject' my suggestions by using the capital\n\
 'D' or 'R' keys (see the keybindings help screen).  You can use capital 'Q' to\n\
-force me to accept the situation currently displayed, in case you want to\n\
+force to accept the situation currently displayed, in case you want to\n\
 override a recommendation or think that the program is mistaken.\n\n\
 \
 Press <space> to leave help and enter the sub-list; remember: press '?' for help.\n")
 };
 
 const struct helpmessage hlp_displayexplain1 = {
-  N_("Display, part 1: package listing and status chars"), N_("\
+	N_("Display, part 1: package listing and status chars"), N_("\
 The top half of the screen shows a list of packages.  For each package you see\n\
 four columns for its current status on the system and mark.  In terse mode (use\n\
 'v' to toggle verbose display) these are single characters, from left to right:\n\n\
@@ -140,7 +140,7 @@ four columns for its current status on the system and mark.  In terse mode (use\
  Mark: what is requested for this package:\n\
   '*': marked for installation or upgrade;\n\
   '-': marked for removal, but any configuration files will remain;\n\
-  '=': on hold: package will not be processed at all;\n\
+  '=': on hold: package will not be installed, upgraded or removed;\n\
   '_': marked for purge completely - even remove configuration;\n\
   'n': package is new and has yet to be marked for install/remove/&c.\n\n\
 \
@@ -149,7 +149,7 @@ available version numbers (shift-V to display/hide) and summary description.\n")
 };
 
 const struct helpmessage hlp_displayexplain2 = {
-  N_("Display, part 2: list highlight; information display"), N_("\
+	N_("Display, part 2: list highlight; information display"), N_("\
 * Highlight: One line in the package list will be highlighted.  It indicates\n\
   which package(s) will be affected by presses of '+', '-' and '_'.\n\n\
 \
@@ -173,7 +173,7 @@ const struct helpmessage hlp_displayexplain2 = {
 };
 
 const struct helpmessage hlp_methintro = {
-  N_("Introduction to method selection display"), N_("\
+	N_("Introduction to method selection display"), N_("\
 dselect and dpkg can do automatic installation, loading the package files to be\n\
 installed from one of a number of different possible places.\n\n\
 \
@@ -193,7 +193,7 @@ menu reachable by pressing '?'.\n")
 };
 
 const struct helpmessage hlp_methkeys = {
-  N_("Keystrokes for method selection"), N_("\
+	N_("Keystrokes for method selection"), N_("\
 Motion keys: Next/Previous, Top/End, Up/Down, Backwards/Forwards:\n\
   j, Down-arrow         k, Up-arrow             move highlight\n\
   N, Page-down, Space   P, Page-up, Backspace   scroll list by 1 page\n\
