@@ -81,11 +81,9 @@ pkg_infodb_link_multiarch_files(void)
 	struct varbuf_state newname_state;
 
 	varbuf_add_dir(&oldname, pkg_infodb_get_dir());
-	varbuf_end_str(&oldname);
 	varbuf_snapshot(&oldname, &oldname_state);
 
-	varbuf_add_buf(&newname, oldname.buf, oldname.used);
-	varbuf_end_str(&newname);
+	varbuf_set_varbuf(&newname, &oldname);
 	varbuf_snapshot(&newname, &newname_state);
 
 	db_dir = opendir(pkg_infodb_get_dir());
@@ -107,9 +105,7 @@ pkg_infodb_link_multiarch_files(void)
 		if (dot == NULL)
 			continue;
 
-		varbuf_reset(&pkgname);
-		varbuf_add_buf(&pkgname, db_de->d_name, dot - db_de->d_name);
-		varbuf_end_str(&pkgname);
+		varbuf_set_buf(&pkgname, db_de->d_name, dot - db_de->d_name);
 
 		 /* Skip files already converted. */
 		if (strchr(pkgname.buf, ':'))
@@ -120,7 +116,7 @@ pkg_infodb_link_multiarch_files(void)
 			if (pkg->status != PKG_STAT_NOTINSTALLED)
 				break;
 		if (!pkg) {
-			warning(_("info file %s/%s not associated to any package"),
+			warning(_("metadata file %s/%s not associated to any package"),
 			        pkg_infodb_get_dir(), db_de->d_name);
 			continue;
 		}
@@ -134,16 +130,14 @@ pkg_infodb_link_multiarch_files(void)
 
 		varbuf_rollback(&oldname_state);
 		varbuf_add_str(&oldname, db_de->d_name);
-		varbuf_end_str(&oldname);
 
 		varbuf_rollback(&newname_state);
 		varbuf_add_pkgbin_name(&newname, pkg, &pkg->installed, pnaw_always);
 		varbuf_add_char(&newname, '.');
 		varbuf_add_str(&newname, filetype);
-		varbuf_end_str(&newname);
 
 		if (link(oldname.buf, newname.buf) && errno != EEXIST)
-			ohshite(_("error creating hard link '%.255s'"),
+			ohshite(_("error creating hard link '%s'"),
 			        newname.buf);
 		rename_head = rename_node_new(oldname.buf, newname.buf, rename_head);
 	}
@@ -164,15 +158,15 @@ cu_abort_db_upgrade(int argc, void **argv)
 	while (rename_head) {
 		next = rename_head->next;
 		if (link(rename_head->new, rename_head->old) && errno != EEXIST)
-			ohshite(_("error creating hard link '%.255s'"),
+			ohshite(_("error creating hard link '%s'"),
 			        rename_head->old);
 		if (unlink(rename_head->new))
-			ohshite(_("cannot remove '%.250s'"), rename_head->new);
+			ohshite(_("cannot remove '%s'"), rename_head->new);
 		rename_node_free(rename_head);
 		rename_head = next;
 	}
 	if (unlink(file->name_new) && errno != ENOENT)
-		ohshite(_("cannot remove '%.250s'"), file->name_new);
+		ohshite(_("cannot remove '%s'"), file->name_new);
 
 	atomic_file_free(file);
 }
@@ -198,7 +192,7 @@ pkg_infodb_unlink_monoarch_files(void)
 	while (rename_head) {
 		next = rename_head->next;
 		if (unlink(rename_head->old))
-			ohshite(_("cannot remove '%.250s'"), rename_head->old);
+			ohshite(_("cannot remove '%s'"), rename_head->old);
 		rename_node_free(rename_head);
 		rename_head = next;
 	}
