@@ -129,8 +129,7 @@ meminfo_get_available_from_file(const char *filename, uint64_t *val)
 			if ((num == INTMAX_MAX) && errno == ERANGE)
 				return MEMINFO_INT_MAX;
 			/* It should end with ' kB\n'. */
-			if (*end != ' ' || *(end + 1) != 'k' ||
-			    *(end + 2) != 'B')
+			if (end[0] != ' ' || end[1] != 'k' || end[2] != 'B')
 				return MEMINFO_NO_UNIT;
 
 			/* This should not overflow, but just in case. */
@@ -160,7 +159,7 @@ meminfo_get_available_from_file(const char *filename, uint64_t *val)
 enum meminfo_error_code
 meminfo_get_available(uint64_t *val)
 {
-#ifdef __linux__
+#if defined(__linux__) || defined(__GNU__)
 	return meminfo_get_available_from_file("/proc/meminfo", val);
 #else
 	return MEMINFO_NO_FILE;
