@@ -21,17 +21,16 @@ Dpkg::Control::Fields - manage (list of official) control fields
 
 =head1 DESCRIPTION
 
-The module contains a list of vendor-neutral and vendor-specific fieldnames
+The module contains a list of vendor-neutral and vendor-specific field names
 with associated meta-data explaining in which type of control information
-they are allowed. The vendor-neutral fieldnames and all functions are
-inherited from Dpkg::Control::FieldsCore.
+they are allowed. The vendor-neutral field names and all functions are
+inherited from L<Dpkg::Control::FieldsCore>.
 
 =cut
 
 package Dpkg::Control::Fields 1.00;
 
-use strict;
-use warnings;
+use v5.36;
 
 our @EXPORT = @Dpkg::Control::FieldsCore::EXPORT;
 
@@ -41,9 +40,10 @@ use Exporter qw(import);
 use Dpkg::Control::FieldsCore;
 use Dpkg::Vendor qw(run_vendor_hook);
 
-# Register vendor specifics fields
+# Register vendor specifics fields.
 foreach my $op (run_vendor_hook('register-custom-fields')) {
-    next if not (defined $op and ref $op); # Skip when not implemented by vendor
+    # Skip when not implemented by vendor.
+    next if not (defined $op and ref $op);
     my $func = shift @$op;
     if ($func eq 'register') {
         my ($field, $allowed_type, @opts) = @{$op};
