@@ -1,4 +1,5 @@
 # Copyright © 2009 Raphaël Hertzog <hertzog@debian.org>
+# Copyright © 2012-2017 Guillem Jover <guillem@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,12 +14,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::Index;
+=encoding utf8
 
-use strict;
-use warnings;
+=head1 NAME
 
-our $VERSION = '1.00';
+Dpkg::Index - generic index of control information
+
+=head1 DESCRIPTION
+
+This class represent a set of L<Dpkg::Control> objects.
+
+=cut
+
+package Dpkg::Index 3.00;
+
+use v5.36;
 
 use Dpkg::Gettext;
 use Dpkg::ErrorHandling;
@@ -30,16 +40,6 @@ use overload
     '@{}' => sub { return $_[0]->{order} },
     fallback => 1;
 
-=encoding utf8
-
-=head1 NAME
-
-Dpkg::Index - generic index of control information
-
-=head1 DESCRIPTION
-
-This object represent a set of Dpkg::Control objects.
-
 =head1 METHODS
 
 =over 4
@@ -55,15 +55,17 @@ sub new {
     my $class = ref($this) || $this;
 
     my $self = {
-	items => {},
-	order => [],
-	get_key_func => sub { return $_[0]->{Package} },
-	type => CTRL_UNKNOWN,
+        items => {},
+        order => [],
+        unique_tuple_key => 1,
+        get_key_func => sub { return $_[0]->{Package} },
+        type => CTRL_UNKNOWN,
+        item_opts => {},
     };
     bless $self, $class;
     $self->set_options(%opts);
     if (exists $opts{load}) {
-	$self->load($opts{load});
+        $self->load($opts{load});
     }
 
     return $self;
@@ -71,37 +73,103 @@ sub new {
 
 =item $index->set_options(%opts)
 
-The "type" option is checked first to define default values for other
-options. Here are the relevant options: "get_key_func" is a function
-returning a key for the item passed in parameters. The index can only
-contain one item with a given key. The function used depends on the
-type: for CTRL_INFO_PKG, CTRL_INDEX_SRC, CTRL_INDEX_PKG and CTRL_PKG_DEB
-it's simply the Package field; for CTRL_PKG_SRC and CTRL_INFO_SRC, it's
-the Source field; for CTRL_CHANGELOG it's the Source and the Version
-fields (concatenated with an intermediary "_"); for CTRL_TESTS is either
-the Tests or Test-Command fields; for CTRL_FILE_CHANGES it's
-the Source, Version and Architecture fields (concatenated with "_");
-for CTRL_FILE_VENDOR it's the Vendor field; for CTRL_FILE_STATUS it's the
-Package and Architecture fields (concatenated with "_"). Otherwise it's
-the Package field by default.
+Change the value of some options.
+
+Options:
+
+=over
+
+=item B<type>
+
+Set the deb822 control type, used to setup default values for other options.
+
+=item B<item_opts>
+
+Set a hash reference that will be passed to the item constructor in
+the $index->new_item() method.
+The index can only contain one item with a given key.
+
+=item B<unique_tuple_key>
+
+Set a boolean requesting whether the default key should be the unique tuple
+(default to true).
+
+=item B<get_key_func>
+
+Set a function returning a key for the item passed in parameters.
+
+The default depends on the type:
+
+=over
+
+=item *
+
+for CTRL_TMPL_SRC, it is the Source field;
+
+=item *
+
+for CTRL_REPO_SRC and CTRL_DSC it is the Package and Version fields
+(concatenated with "_") when B<unique_tuple_key> is true (the default), or
+otherwise the Package field;
+
+=item *
+
+for CTRL_TMPL_PKG it is simply the Package field;
+
+=item *
+
+for CTRL_REPO_PKG and CTRL_DEB it is the Package, Version and
+Architecture fields (concatenated with "_") when B<unique_tuple_key> is
+true (the default) or otherwise the Package field;
+
+=item *
+
+for CTRL_CHANGELOG it is the Source and the Version fields (concatenated
+with an intermediary "_");
+
+=item *
+
+for CTRL_TESTS is an integer index (0-based) corresponding to the Tests or
+Test-Command field stanza;
+
+=item *
+
+for CTRL_FILE_CHANGES it is the Source, Version and Architecture fields
+(concatenated with "_");
+
+=item *
+
+for CTRL_FILE_VENDOR it is the Vendor field;
+
+=item *
+
+for CTRL_FILE_STATUS it is the Package and Architecture fields (concatenated
+with "_");
+
+=item *
+
+otherwise it is the Package field by default.
+
+=back
+
+=back
 
 =cut
 
 sub set_options {
     my ($self, %opts) = @_;
 
-    # Default values based on type
+    # Default values based on type.
     if (exists $opts{type}) {
         my $t = $opts{type};
-        if ($t == CTRL_INFO_PKG or $t == CTRL_INDEX_SRC or
-	         $t == CTRL_INDEX_PKG or $t == CTRL_PKG_DEB) {
-	    $self->{get_key_func} = sub { return $_[0]->{Package}; };
-        } elsif ($t == CTRL_PKG_SRC or $t == CTRL_INFO_SRC) {
-	    $self->{get_key_func} = sub { return $_[0]->{Source}; };
+        if ($t == CTRL_TMPL_PKG) {
+            $self->{get_key_func} = sub { return $_[0]->{Package}; };
+        } elsif ($t == CTRL_TMPL_SRC) {
+            $self->{get_key_func} = sub { return $_[0]->{Source}; };
         } elsif ($t == CTRL_CHANGELOG) {
-	    $self->{get_key_func} = sub {
-		return $_[0]->{Source} . '_' . $_[0]->{Version};
-	    };
+            $self->{get_key_func} = sub {
+                return $_[0]->{Source} . '_' . $_[0]->{Version};
+            };
         } elsif ($t == CTRL_COPYRIGHT_HEADER) {
             # This is a bit pointless, because the value will almost always
             # be the same, but guarantees that we use a known field.
@@ -112,23 +180,44 @@ sub set_options {
             $self->{get_key_func} = sub { return $_[0]->{License}; };
         } elsif ($t == CTRL_TESTS) {
             $self->{get_key_func} = sub {
-                return $_[0]->{Tests} || $_[0]->{'Test-Command'};
+                return scalar @{$self->{order}};
             };
+        } elsif ($t == CTRL_REPO_SRC or $t == CTRL_DSC) {
+            if ($opts{unique_tuple_key} // $self->{unique_tuple_key}) {
+                $self->{get_key_func} = sub {
+                    return $_[0]->{Package} . '_' . $_[0]->{Version};
+                };
+            } else {
+                $self->{get_key_func} = sub {
+                    return $_[0]->{Package};
+                };
+            }
+        } elsif ($t == CTRL_REPO_PKG or $t == CTRL_DEB) {
+            if ($opts{unique_tuple_key} // $self->{unique_tuple_key}) {
+                $self->{get_key_func} = sub {
+                    return $_[0]->{Package} . '_' . $_[0]->{Version} . '_' .
+                           $_[0]->{Architecture};
+                };
+            } else {
+                $self->{get_key_func} = sub {
+                    return $_[0]->{Package};
+                };
+            }
         } elsif ($t == CTRL_FILE_CHANGES) {
-	    $self->{get_key_func} = sub {
-		return $_[0]->{Source} . '_' . $_[0]->{Version} . '_' .
-		       $_[0]->{Architecture};
-	    };
+            $self->{get_key_func} = sub {
+                return $_[0]->{Source} . '_' . $_[0]->{Version} . '_' .
+                       $_[0]->{Architecture};
+            };
         } elsif ($t == CTRL_FILE_VENDOR) {
-	    $self->{get_key_func} = sub { return $_[0]->{Vendor}; };
+            $self->{get_key_func} = sub { return $_[0]->{Vendor}; };
         } elsif ($t == CTRL_FILE_STATUS) {
-	    $self->{get_key_func} = sub {
-		return $_[0]->{Package} . '_' . $_[0]->{Architecture};
-	    };
+            $self->{get_key_func} = sub {
+                return $_[0]->{Package} . '_' . $_[0]->{Architecture};
+            };
         }
     }
 
-    # Options set by the user override default values
+    # Options set by the user override default values.
     $self->{$_} = $opts{$_} foreach keys %opts;
 }
 
@@ -157,16 +246,11 @@ sub add {
 
     $key //= $self->{get_key_func}($item);
     if (not exists $self->{items}{$key}) {
-	push @{$self->{order}}, $key;
+        push @{$self->{order}}, $key;
     }
     $self->{items}{$key} = $item;
 }
 
-=item $index->load($file)
-
-Reads the file and creates all items parsed. Returns the number of items
-parsed. Handles compressed files transparently based on their extensions.
-
 =item $index->parse($fh, $desc)
 
 Reads the filehandle and creates all items parsed. When called multiple
@@ -181,29 +265,33 @@ sub parse {
     my $item = $self->new_item();
     my $i = 0;
     while ($item->parse($fh, $desc)) {
-	$self->add($item);
-	$item = $self->new_item();
-	$i++;
+        $self->add($item);
+        $item = $self->new_item();
+        $i++;
     }
     return $i;
 }
 
-=item $index->save($file)
+=item $index->load($file)
 
-Writes the content of the index in a file. Auto-compresses files
-based on their extensions.
+Reads the file and creates all items parsed. Returns the number of items
+parsed. Handles compressed files transparently based on their extensions.
 
 =item $item = $index->new_item()
 
 Creates a new item. Mainly useful for derived objects that would want
-to override this method to return something else than a Dpkg::Control
+to override this method to return something else than a L<Dpkg::Control>
 object.
 
 =cut
 
 sub new_item {
     my $self = shift;
-    return Dpkg::Control->new(type => $self->{type});
+
+    return Dpkg::Control->new(
+        %{$self->{item_opts}},
+        type => $self->{type},
+    );
 }
 
 =item $item = $index->get_by_key($key)
@@ -231,22 +319,24 @@ that must be equal to the field value.
 sub get_keys {
     my ($self, %crit) = @_;
     my @selected = @{$self->{order}};
-    foreach my $s_crit (keys %crit) { # search criteria
-	if (ref($crit{$s_crit}) eq 'Regexp') {
-	    @selected = grep {
-		exists $self->{items}{$_}{$s_crit} and
-		       $self->{items}{$_}{$s_crit} =~ $crit{$s_crit}
-	    } @selected;
-	} elsif (ref($crit{$s_crit}) eq 'CODE') {
-	    @selected = grep {
-		&{$crit{$s_crit}}($self->{items}{$_}{$s_crit});
-	    } @selected;
-	} else {
-	    @selected = grep {
-		exists $self->{items}{$_}{$s_crit} and
-		       $self->{items}{$_}{$s_crit} eq $crit{$s_crit}
-	    } @selected;
-	}
+
+    # Search criteria.
+    foreach my $s_crit (keys %crit) {
+        if (ref($crit{$s_crit}) eq 'Regexp') {
+            @selected = grep {
+                exists $self->{items}{$_}{$s_crit} and
+                       $self->{items}{$_}{$s_crit} =~ $crit{$s_crit}
+            } @selected;
+        } elsif (ref($crit{$s_crit}) eq 'CODE') {
+            @selected = grep {
+                $crit{$s_crit}->($self->{items}{$_}{$s_crit});
+            } @selected;
+        } else {
+            @selected = grep {
+                exists $self->{items}{$_}{$s_crit} and
+                       $self->{items}{$_}{$s_crit} eq $crit{$s_crit}
+            } @selected;
+        }
     }
     return @selected;
 }
@@ -285,9 +375,9 @@ sub remove {
     my @keys = $self->get_keys(%crit);
     my (%keys, @ret);
     foreach my $key (@keys) {
-	$keys{$key} = 1;
-	push @ret, $self->{items}{$key} if defined wantarray;
-	delete $self->{items}{$key};
+        $keys{$key} = 1;
+        push @ret, $self->{items}{$key} if defined wantarray;
+        delete $self->{items}{$key};
     }
     @{$self->{order}} = grep { not exists $keys{$_} } @{$self->{order}};
     return @ret;
@@ -296,9 +386,19 @@ sub remove {
 =item $index->merge($other_index, %opts)
 
 Merge the entries of the other index. While merging, the keys of the merged
-index are used, they are not re-computed (unless you have set the options
-"keep_keys" to "0"). It's your responsibility to ensure that they have been
-computed with the same function.
+index are used, they are not re-computed. It's your responsibility to ensure
+that they have been computed with the same function.
+
+Options:
+
+=over
+
+=item B<keep_keys>
+
+Set whether to re-compute the keys from the other index.
+Defaults to 1.
+
+=back
 
 =cut
 
@@ -306,7 +406,7 @@ sub merge {
     my ($self, $other, %opts) = @_;
     $opts{keep_keys} //= 1;
     foreach my $key ($other->get_keys()) {
-	$self->add($other->get_by_key($key), $opts{keep_keys} ? $key : undef);
+        $self->add($other->get_by_key($key), $opts{keep_keys} ? $key : undef);
     }
 }
 
@@ -321,25 +421,24 @@ items themselves as parameters and not the keys.
 sub sort {
     my ($self, $func) = @_;
     if (defined $func) {
-	@{$self->{order}} = sort {
-	    &$func($self->{items}{$a}, $self->{items}{$b})
-	} @{$self->{order}};
+        @{$self->{order}} = sort {
+            $func->($self->{items}{$a}, $self->{items}{$b})
+        } @{$self->{order}};
     } else {
-	@{$self->{order}} = sort @{$self->{order}};
+        @{$self->{order}} = sort @{$self->{order}};
     }
 }
 
-=item $str = $index->output()
+=item $str = $index->output([$fh])
 
 =item "$index"
 
-Get a string representation of the index. The Dpkg::Control objects are
+Get a string representation of the index. The L<Dpkg::Control> objects are
 output in the order which they have been read or added except if the order
 have been changed with sort().
 
-=item $index->output($fh)
-
-Print the string representation of the index to a filehandle.
+Print the string representation of the index to a filehandle if $fh has
+been passed.
 
 =cut
 
@@ -347,20 +446,43 @@ sub output {
     my ($self, $fh) = @_;
     my $str = '';
     foreach my $key ($self->get_keys()) {
-	if (defined $fh) {
-	    print { $fh } $self->get_by_key($key) . "\n";
-	}
-	if (defined wantarray) {
-	    $str .= $self->get_by_key($key) . "\n";
-	}
+        if (defined $fh) {
+            print { $fh } $self->get_by_key($key) . "\n";
+        }
+        if (defined wantarray) {
+            $str .= $self->get_by_key($key) . "\n";
+        }
     }
     return $str;
 }
 
+=item $index->save($file)
+
+Writes the content of the index in a file. Auto-compresses files
+based on their extensions.
+
 =back
 
 =head1 CHANGES
 
+=head2 Version 3.00 (dpkg 1.21.2)
+
+Change behavior: The CTRL_TESTS key now defaults to a stanza index.
+
+=head2 Version 2.01 (dpkg 1.20.6)
+
+New option: Add new "item_opts" option.
+
+=head2 Version 2.00 (dpkg 1.20.0)
+
+Change behavior: The "unique_tuple_key" option now defaults to true.
+
+=head2 Version 1.01 (dpkg 1.19.0)
+
+New option: Add new "unique_tuple_key" option to $index->set_options() to set
+better default "get_key_func" options, which will become the default behavior
+in 1.20.x.
+
 =head2 Version 1.00 (dpkg 1.15.6)
 
 Mark the module as public.
