@@ -22,8 +22,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-use strict;
-use warnings;
+use v5.36;
 
 use List::Util qw(any);
 use Cwd;
@@ -116,7 +115,11 @@ sub parse_status {
         }
 
         if (/^Provides: (.*)$/m) {
-            my $provides = deps_parse($1, reduce_arch => 1, union => 1);
+            my $provides = deps_parse($1,
+                reduce_arch => 1,
+                virtual => 1,
+                union => 1,
+            );
 
             next if not defined $provides;
 
@@ -142,20 +145,24 @@ sub parse_status {
 }
 
 sub append_deps {
-    my $pkgs = shift;
+    my ($pkgs, @deps) = @_;
 
-    foreach my $dep_str (@_) {
+    foreach my $dep_str (@deps) {
         next unless $dep_str;
 
-        my $deps = deps_parse($dep_str, reduce_restrictions => 1,
-                              build_dep => 1,
-                              build_profiles => \@build_profiles);
+        my $deps = deps_parse($dep_str,
+            reduce_restrictions => 1,
+            build_dep => 1,
+            build_profiles => \@build_profiles,
+        );
 
         # We add every sub-dependencies as we cannot know which package in
         # an OR dependency has been effectively used.
         deps_iterate($deps, sub {
+            my $pkg = shift;
+
             push @{$pkgs},
-                $_[0]->{package} . (defined $_[0]->{archqual} ? ':' . $_[0]->{archqual} : '');
+                $pkg->{package} . (defined $pkg->{archqual} ? ':' . $pkg->{archqual} : '');
             1
         });
     }
@@ -199,7 +206,7 @@ sub collect_installed_builddeps {
         my $pkg;
         my $qualified_pkg_name;
         foreach my $installed_pkg (@{$facts->{pkg}->{$pkg_name}}) {
-            if (!defined $required_architecture ||
+            if (! defined $required_architecture ||
                 $required_architecture eq $installed_pkg->{architecture}) {
                 $pkg = $installed_pkg;
                 $qualified_pkg_name = $pkg_name . ':' . $installed_pkg->{architecture};
@@ -211,7 +218,7 @@ sub collect_installed_builddeps {
             my $architecture = $pkg->{architecture};
             my $new_deps_str = defined $depends->{$qualified_pkg_name} ? deps_concat(@{$depends->{$qualified_pkg_name}}) : '';
             my $new_deps = deps_parse($new_deps_str);
-            if (!defined $required_architecture) {
+            if (! defined $required_architecture) {
                 $installed_deps->add(Dpkg::Deps::Simple->new("$pkg_name (= $version)"));
             } else {
                 $installed_deps->add(Dpkg::Deps::Simple->new("$qualified_pkg_name (= $version)"));
@@ -237,13 +244,13 @@ sub collect_installed_builddeps {
                 1
             });
         } elsif (defined $facts->{virtualpkg}->{$pkg_name}) {
-            # virtual package: we cannot know for sure which implementation
-            # is the one that has been used, so let's add them all...
+            # Virtual package: we cannot know for sure which implementation
+            # is the one that has been used, so let us add them all.
             foreach my $provided (@{$facts->{virtualpkg}->{$pkg_name}}) {
                 push @unprocessed_pkgs, $provided->{provider};
             }
         }
-        # else: it is a package in an OR dependency that has been otherwise
+        # Else: it is a package in an OR dependency that has been otherwise
         # satisfied.
     }
     $installed_deps->simplify_deps(Dpkg::Deps::KnownFacts->new());
@@ -282,7 +289,7 @@ sub is_cross_executable {
         to_string => \$stdout,
         error_to_string => \$stderr,
         wait_child => 1,
-        nocheck => 1,
+        no_check => 1,
     );
     if ($?) {
         print { *STDOUT } $stdout;
@@ -299,7 +306,7 @@ sub is_cross_executable {
         error_to_file => '/dev/null',
         to_string => \$stdout,
         wait_child => 1,
-        nocheck => 1,
+        no_check => 1,
     );
 
     return 1 if $? == 0 && $stdout eq 'ok';
@@ -394,7 +401,7 @@ while (@ARGV) {
     } elsif (m/^-O(.*)$/) {
         $outputfile = $1;
     } elsif (m/^(--buildinfo-id)=.*$/) {
-        # Deprecated option
+        # Deprecated option.
         warning(g_('%s is deprecated; it is without effect'), $1);
     } elsif (m/^--always-include-kernel$/) {
         $use_feature{kernel} = 1;
@@ -418,14 +425,16 @@ my $fields = Dpkg::Control->new(type => CTRL_FILE_BUILDINFO);
 my $dist = Dpkg::Dist::Files->new();
 
 # Retrieve info from the current changelog entry.
-my %options = (file => $changelogfile);
-$options{changelogformat} = $changelogformat if $changelogformat;
-my $changelog = changelog_parse(%options);
+my %changelog_opts = (
+    filename => $changelogfile,
+);
+$changelog_opts{changelogformat} = $changelogformat if $changelogformat;
+my $changelog = changelog_parse(%changelog_opts);
 
 # Retrieve info from the former changelog entry to handle binNMUs.
-$options{count} = 1;
-$options{offset} = 1;
-my $prev_changelog = changelog_parse(%options);
+$changelog_opts{count} = 1;
+$changelog_opts{offset} = 1;
+my $prev_changelog = changelog_parse(%changelog_opts);
 
 my $sourceversion = Dpkg::Version->new($changelog->{'Binary-Only'} ?
                     $prev_changelog->{'Version'} : $changelog->{'Version'});
@@ -498,7 +507,9 @@ $fields->{'Build-Architecture'} = get_build_arch();
 $fields->{'Build-Date'} = get_build_date();
 
 if ($use_feature{kernel}) {
-    my (undef, undef, $kern_rel, $kern_ver, undef) = POSIX::uname();
+    my ($kern_rel, $kern_ver);
+
+    ((undef) x 2, $kern_rel, $kern_ver, undef) = POSIX::uname();
     $fields->{'Build-Kernel-Version'} = "$kern_rel $kern_ver";
 }
 
@@ -550,11 +561,13 @@ if ($stdout) {
 if ($stdout) {
     $fields->output(\*STDOUT);
 } else {
-    my $section = $control->get_source->{'Section'} || '-';
-    my $priority = $control->get_source->{'Priority'} || '-';
+    my %fileprop;
+    foreach my $f (qw(Section Priority)) {
+        $fileprop{lc $f} = $control->get_source->{$f} || field_get_default_value($f);
+    }
 
     # Obtain a lock on debian/control to avoid simultaneous updates
-    # of debian/files when parallel building is in use
+    # of debian/files when parallel building is in use.
     my $lockfh;
     my $lockfile = 'debian/control';
     $lockfile = $controlfile if not -e $lockfile;
@@ -577,13 +590,13 @@ if ($stdout) {
         }
     }
 
-    $dist->add_file($buildinfo, $section, $priority);
+    $dist->add_file($buildinfo, @fileprop{qw(section priority)});
     $dist->save("$fileslistfile.new");
 
     rename "$fileslistfile.new", $fileslistfile
         or syserr(g_('install new files list file'));
 
-    # Release the lock
+    # Release the lock.
     close $lockfh or syserr(g_('cannot close %s'), $lockfile);
 
     $fields->save("$outputfile.new");
@@ -591,5 +604,3 @@ if ($stdout) {
     rename "$outputfile.new", $outputfile
         or syserr(g_("cannot install output buildinfo file '%s'"), $outputfile);
 }
-
-1;
